==> kuiper-service-2.0.2.52-Release-sources.jar: com/bizunited/platform/kuiper/entity/TemplateGroupEntity.java <==
package com.bizunited.platform.kuiper.entity;

import java.util.Set;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.JoinColumn;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;
import javax.persistence.Table;

import com.bizunited.platform.core.entity.UuidEntity;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;

/**
 * 模板分组信息，专门用于进行对主模型的中“分组”属性的描述
 * 一个分组只可能属于一个主模型。而且主模型和相关分组信息的对应关系只可能是OneToOne
 * @author yinwenjie
 */
@Entity
@Table(name="engine_form_group")
@org.hibernate.annotations.Table(appliesTo = "engine_form_group" , comment = "模板分组信息，专门用于进行对主模型的中“分组”属性的描述")
public class TemplateGroupEntity extends UuidEntity {
  /**
   * 
   */
  private static final long serialVersionUID = 8476787433104747941L;
  /**
   * 当前表单模板分组可能对应的表单模板关联信息（表单模板编号）
   */
  @OneToOne(fetch=FetchType.LAZY)
  @JoinColumn(name="parent_template_id" , nullable=true, columnDefinition = "varchar(255) COMMENT '当前表单模板分组可能对应的表单模板关联信息（表单模板编号）'")
  @SaturnColumn(description="上层表单模板信息")
  private TemplateEntity parentTemplate;
  /**
   * 该分组信息适用的表单模板类型，目前有三种：<br>
   * static：该视图适用静态模型<br>
   * dynamic：该视图适用动态模型<br>
   * dsl：该视图适用dsl模型
   */
  @Column(name="group_type" , length=32 , nullable=false, columnDefinition = "varchar(32) COMMENT '目前有三种：static：静态模型;dynamic：动态模型;dsl：dsl模型，其它值无效'")
  @SaturnColumn(description="适用的表单模板类型")
  private String type;
  /**
   * 既是模型中的属性名，一定是英文
   */
  @Column(name="property_name" , length=64 , nullable=false, columnDefinition = "varchar(64) COMMENT '既是模型中的属性名，一定是英文'")
  @SaturnColumn(description="既是主模型中的属性名")
  private String propertyName;
  /**
   * 既是该关联属性在主模型中的属性名，一定是英文
   */
  @Column(name="property_desc" , nullable=false, columnDefinition = "varchar(255) COMMENT '既是该关联属性在主模型中的属性名，一定是英文'")
  @SaturnColumn(description="既是该关联属性在主模型中的属性名")
  private String propertyDesc;
  /**
   * 所关联模型的完整类名，这个类名肯定代表一个存在的模型
   */
  @Column(name="property_classname" , nullable=false, columnDefinition = "varchar(255) COMMENT '所关联模型的完整类名，这个类名肯定代表一个存在的模型'")
  @SaturnColumn(description="所关联模型的完整类名，这个类名肯定代表一个存在的类模型（静态模板使用）")
  private String propertyClassName = "";
  /**
   * 该属性在持久化类中的排序索引。第一个属性编号为0
   */
  @Column(name="cindex" , nullable=false, columnDefinition = "int(11) COMMENT '该属性在持久化类中的排序索引。第一个属性编号为0'")
  @SaturnColumn(description="该属性在持久化类中的排序索引")
  private Integer index = 0;
  /**
   * 使用的查询服务名（静态模板使用）
   */
  @Column(name="query_service" , length=128 , nullable=false, columnDefinition = "varchar(128) COMMENT '使用的查询服务名（静态模板使用）'")
  @SaturnColumn(description="使用的查询服务名")
  private String queryService = "";
  /**
   * 当前数据表，这个信息非常重要（动态模板使用）
   */
  @Column(name="target_table" , length=128 , nullable=false, columnDefinition = "varchar(128) COMMENT '当前数据表，这个信息非常重要（动态模板使用）'")
  @SaturnColumn(description="目标数据表（动态模板使用）")
  private String tableName = "";
  /**
   * 分组数据表上层的主数据表名（动态模型使用）
   */
  @Column(name="parent_tablename" , length=128 , nullable=false, columnDefinition = "varchar(128) COMMENT '分组数据表上层的主数据表名（动态模型使用）'")
  @SaturnColumn(description="上层的主数据表")
  private String parentTableName = "";
  /**
   * 分组模型上层的主信息类名（静态模型使用）
   */
  @Column(name="parent_classname" , length=128 , nullable=false, columnDefinition = "varchar(128) COMMENT '分组模型上层的主信息类名（静态模型使用）'")
  @SaturnColumn(description="上层的主信息类名")
  private String parentClassName = "";
  /**
   * 模型的完整包名
   */
  @Column(name="pkage" , nullable=false, columnDefinition = "varchar(255) COMMENT '模型的完整包名'")
  @SaturnColumn(description="完整包名")
  private String pkage = "";
  /**
   * 模型的类简称（静态模型使用）
   */
  @Column(name="simple_classname" , length=128 , nullable=false, columnDefinition = "varchar(128) COMMENT '模型的类简称（静态模型使用）'")
  @SaturnColumn(description="类简称")
  private String simpleClassName;
  /**
   * 是否有数据层信息进行支撑
   */
  @Column(name="repository_entity" , nullable=false, columnDefinition = "bit(1) COMMENT '是否有数据层信息进行支撑'")
  @SaturnColumn(description="是否有数据层支撑")
  private Boolean repositoryEntity;
  /**
   * 分组中的一般属性信息
   */
  @OneToMany(fetch=FetchType.LAZY , mappedBy="currentGroup")
  @SaturnColumn(description="分组中的一般属性信息")
  private Set<TemplatePropertyEntity> properties;
  /**
   * 分组中的关联属性信息
   */
  @OneToMany(fetch=FetchType.LAZY , mappedBy="currentGroup")
  @SaturnColumn(description="分组中的关联属性信息")
  private Set<TemplateRelationEntity> relations;
  /**
   * 分组中可能对应的明细信息
   */
  @OneToMany(fetch=FetchType.LAZY , mappedBy="parentGroup")
  @SaturnColumn(description="分组中的关联属性信息")
  private Set<TemplateItemEntity> itemRelations;
  
  public String getType() {
    return type;
  }
  public void setType(String type) {
    this.type = type;
  }
  public String getPropertyName() {
    return propertyName;
  }
  public void setPropertyName(String propertyName) {
    this.propertyName = propertyName;
  }
  public String getPropertyDesc() {
    return propertyDesc;
  }
  public void setPropertyDesc(String propertyDesc) {
    this.propertyDesc = propertyDesc;
  }
  public Integer getIndex() {
    return index;
  }
  public void setIndex(Integer index) {
    this.index = index;
  }
  public String getPropertyClassName() {
    return propertyClassName;
  }
  public void setPropertyClassName(String propertyClassName) {
    this.propertyClassName = propertyClassName;
  }
  public String getQueryService() {
    return queryService;
  }
  public void setQueryService(String queryService) {
    this.queryService = queryService;
  }
  public String getTableName() {
    return tableName;
  }
  public void setTableName(String tableName) {
    this.tableName = tableName;
  }
  public String getParentTableName() {
    return parentTableName;
  }
  public void setParentTableName(String parentTableName) {
    this.parentTableName = parentTableName;
  }
  public String getParentClassName() {
    return parentClassName;
  }
  public void setParentClassName(String parentClassName) {
    this.parentClassName = parentClassName;
  }
  public String getPkage() {
    return pkage;
  }
  public void setPkage(String pkage) {
    this.pkage = pkage;
  }
  public String getSimpleClassName() {
    return simpleClassName;
  }
  public void setSimpleClassName(String simpleClassName) {
    this.simpleClassName = simpleClassName;
  }
  public Boolean getRepositoryEntity() {
    return repositoryEntity;
  }
  public void setRepositoryEntity(Boolean repositoryEntity) {
    this.repositoryEntity = repositoryEntity;
  }
  public TemplateEntity getParentTemplate() {
    return parentTemplate;
  }
  public void setParentTemplate(TemplateEntity parentTemplate) {
    this.parentTemplate = parentTemplate;
  }
  public Set<TemplatePropertyEntity> getProperties() {
    return properties;
  }
  public void setProperties(Set<TemplatePropertyEntity> properties) {
    this.properties = properties;
  }
  public Set<TemplateRelationEntity> getRelations() {
    return relations;
  }
  public void setRelations(Set<TemplateRelationEntity> relations) {
    this.relations = relations;
  }
  public Set<TemplateItemEntity> getItemRelations() {
    return itemRelations;
  }
  public void setItemRelations(Set<TemplateItemEntity> itemRelations) {
    this.itemRelations = itemRelations;
  }
}

==> kuiper-service-2.2.1.54-Release-sources.jar: com/bizunited/platform/kuiper/entity/TemplateGroupEntity.java <==
package com.bizunited.platform.kuiper.entity;

import com.bizunited.platform.common.entity.UuidEntity;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import io.swagger.annotations.ApiModelProperty;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.JoinColumn;
import javax.persistence.OneToMany;
import javax.persistence.OneToOne;
import javax.persistence.Table;
import java.util.Set;

/**
 * 模板分组信息，专门用于进行对主模型的中“分组”属性的描述
 * 一个分组只可能属于一个主模型。而且主模型和相关分组信息的对应关系只可能是OneToOne
 * @author yinwenjie
 */
@Entity
@Table(name="engine_form_group")
@org.hibernate.annotations.Table(appliesTo = "engine_form_group" , comment = "模板分组信息，专门用于进行对主模型的中“分组”属性的描述")
public class TemplateGroupEntity extends UuidEntity {
  /**
   * 
   */
  private static final long serialVersionUID = 8476787433104747941L;
  /**
   * 当前表单模板分组可能对应的表单模板关联信息（表单模板编号）
   */
  @OneToOne(fetch=FetchType.LAZY)
  @JoinColumn(name="parent_template_id" , nullable=true, columnDefinition = "varchar(255) COMMENT '当前表单模板分组可能对应的表单模板关联信息（表单模板编号）'")
  @SaturnColumn(description="上层表单模板信息")
  private TemplateEntity parentTemplate;
  /**
   * 该分组信息适用的表单模板类型，目前有三种：<br>
   * static：该视图适用静态模型<br>
   * dynamic：该视图适用动态模型<br>
   * dsl：该视图适用dsl模型
   */
  @Column(name="group_type" , length=32 , nullable=false, columnDefinition = "varchar(32) COMMENT '目前有三种：static：静态模型;dynamic：动态模型;dsl：dsl模型，其它值无效'")
  @SaturnColumn(description="适用的表单模板类型")
  private String type;
  /**
   * 既是模型中的属性名，一定是英文
   */
  @Column(name="property_name" , length=64 , nullable=false, columnDefinition = "varchar(64) COMMENT '既是模型中的属性名，一定是英文'")
  @SaturnColumn(description="既是主模型中的属性名")
  private String propertyName;
  /**
   * 既是该关联属性在主模型中的属性名，一定是英文
   */
  @Column(name="property_desc" , nullable=false, columnDefinition = "varchar(255) COMMENT '既是该关联属性在主模型中的属性名，一定是英文'")
  @SaturnColumn(description="既是该关联属性在主模型中的属性名")
  private String propertyDesc;
  /**
   * 所关联模型的完整类名，这个类名肯定代表一个存在的模型
   */
  @Column(name="property_classname" , nullable=false, columnDefinition = "varchar(255) COMMENT '所关联模型的完整类名，这个类名肯定代表一个存在的模型'")
  @SaturnColumn(description="所关联模型的完整类名，这个类名肯定代表一个存在的类模型（静态模板使用）")
  private String propertyClassName = "";
  /**
   * 该属性在持久化类中的排序索引。第一个属性编号为0
   */
  @Column(name="cindex" , nullable=false, columnDefinition = "int(11) COMMENT '该属性在持久化类中的排序索引。第一个属性编号为0'")
  @SaturnColumn(description="该属性在持久化类中的排序索引")
  private Integer index = 0;
  /**
   * 使用的查询服务名（静态模板使用）
   */
  @Column(name="query_service" , length=128 , nullable=false, columnDefinition = "varchar(128) COMMENT '使用的查询服务名（静态模板使用）'")
  @SaturnColumn(description="使用的查询服务名")
  private String queryService = "";
  /**
   * 当前数据表，这个信息非常重要（动态模板使用）
   */
  @Column(name="target_table" , length=128 , nullable=false, columnDefinition = "varchar(128) COMMENT '当前数据表，这个信息非常重要（动态模板使用）'")
  @SaturnColumn(description="目标数据表（动态模板使用）")
  private String tableName = "";
  /**
   * 分组数据表上层的主数据表名（动态模型使用）
   */
  @Column(name="parent_tablename" , length=128 , nullable=false, columnDefinition = "varchar(128) COMMENT '分组数据表上层的主数据表名（动态模型使用）'")
  @SaturnColumn(description="上层的主数据表")
  private String parentTableName = "";
  /**
   * 分组模型上层的主信息类名（静态模型使用）
   */
  @Column(name="parent_classname" , length=128 , nullable=false, columnDefinition = "varchar(128) COMMENT '分组模型上层的主信息类名（静态模型使用）'")
  @SaturnColumn(description="上层的主信息类名")
  private String parentClassName = "";
  /**
   * 模型的完整包名
   */
  @Column(name="pkage" , nullable=false, columnDefinition = "varchar(255) COMMENT '模型的完整包名'")
  @SaturnColumn(description="完整包名")
  private String pkage = "";
  /**
   * 模型的类简称（静态模型使用）
   */
  @Column(name="simple_classname" , length=128 , nullable=false, columnDefinition = "varchar(128) COMMENT '模型的类简称（静态模型使用）'")
  @SaturnColumn(description="类简称")
  private String simpleClassName;
  /**
   * 是否有数据层信息进行支撑
   */
  @Column(name="repository_entity" , nullable=false, columnDefinition = "bit(1) COMMENT '是否有数据层信息进行支撑'")
  @SaturnColumn(description="是否有数据层支撑")
  private Boolean repositoryEntity;
  /**
   * 分组中的一般属性信息
   */
  @OneToMany(fetch=FetchType.LAZY , mappedBy="currentGroup")
  @SaturnColumn(description="分组中的一般属性信息")
  private Set<TemplatePropertyEntity> properties;
  /**
   * 分组中的关联属性信息
   */
  @OneToMany(fetch=FetchType.LAZY , mappedBy="currentGroup")
  @SaturnColumn(description="分组中的关联属性信息")
  private Set<TemplateRelationEntity> relations;
  /**
   * 分组中可能对应的明细信息
   */
  @OneToMany(fetch=FetchType.LAZY , mappedBy="parentGroup")
  @SaturnColumn(description="分组中的关联属性信息")
  private Set<TemplateItemEntity> itemRelations;

  /**
   * 当前项目名工程名
   */
  @ApiModelProperty("当前项目名工程名")
  @Column(name="project_name", nullable = false, columnDefinition = "varchar(255) default '' comment '工程名'")
  @SaturnColumn(description = "工程名")
  private String projectName;

  public String getProjectName() {
    return projectName;
  }

  public void setProjectName(String projectName) {
    this.projectName = projectName;
  }
  
  public String getType() {
    return type;
  }
  public void setType(String type) {
    this.type = type;
  }
  public String getPropertyName() {
    return propertyName;
  }
  public void setPropertyName(String propertyName) {
    this.propertyName = propertyName;
  }
  public String getPropertyDesc() {
    return propertyDesc;
  }
  public void setPropertyDesc(String propertyDesc) {
    this.propertyDesc = propertyDesc;
  }
  public Integer getIndex() {
    return index;
  }
  public void setIndex(Integer index) {
    this.index = index;
  }
  public String getPropertyClassName() {
    return propertyClassName;
  }
  public void setPropertyClassName(String propertyClassName) {
    this.propertyClassName = propertyClassName;
  }
  public String getQueryService() {
    return queryService;
  }
  public void setQueryService(String queryService) {
    this.queryService = queryService;
  }
  public String getTableName() {
    return tableName;
  }
  public void setTableName(String tableName) {
    this.tableName = tableName;
  }
  public String getParentTableName() {
    return parentTableName;
  }
  public void setParentTableName(String parentTableName) {
    this.parentTableName = parentTableName;
  }
  public String getParentClassName() {
    return parentClassName;
  }
  public void setParentClassName(String parentClassName) {
    this.parentClassName = parentClassName;
  }
  public String getPkage() {
    return pkage;
  }
  public void setPkage(String pkage) {
    this.pkage = pkage;
  }
  public String getSimpleClassName() {
    return simpleClassName;
  }
  public void setSimpleClassName(String simpleClassName) {
    this.simpleClassName = simpleClassName;
  }
  public Boolean getRepositoryEntity() {
    return repositoryEntity;
  }
  public void setRepositoryEntity(Boolean repositoryEntity) {
    this.repositoryEntity = repositoryEntity;
  }
  public TemplateEntity getParentTemplate() {
    return parentTemplate;
  }
  public void setParentTemplate(TemplateEntity parentTemplate) {
    this.parentTemplate = parentTemplate;
  }
  public Set<TemplatePropertyEntity> getProperties() {
    return properties;
  }
  public void setProperties(Set<TemplatePropertyEntity> properties) {
    this.properties = properties;
  }
  public Set<TemplateRelationEntity> getRelations() {
    return relations;
  }
  public void setRelations(Set<TemplateRelationEntity> relations) {
    this.relations = relations;
  }
  public Set<TemplateItemEntity> getItemRelations() {
    return itemRelations;
  }
  public void setItemRelations(Set<TemplateItemEntity> itemRelations) {
    this.itemRelations = itemRelations;
  }
}
